@@ -59,6 +59,8 @@
 */
 
 #include "vsearch.h"
+#include <cstdint>  // int32_t
+
 
 /* This file contains code dependent on special cpu features. */
 /* The file may be compiled several times with different cpu options. */
@@ -75,43 +77,39 @@ void increment_counters_from_bitmap(count_t * counters,
 
   unsigned short * p = (unsigned short *)(bitmap);
   int16x8_t * q = (int16x8_t *)(counters);
-  int r = (totalbits + 15) / 16;
+  const auto r = (totalbits + 15) / 16;
 
-  for(int j=0; j<r; j++)
+  for(auto j = 0U; j < r; j++)
     {
-      uint16x8_t r0;
-      uint8x16_t r1, r2, r3, r4;
-      int16x8_t r5, r6;
-
       // load and duplicate short
-      r0 = vdupq_n_u16(*p);
-      p++;
+      uint16x8_t r0 = vdupq_n_u16(*p);
+      ++p;
 
       // cast to bytes
-      r1 = vreinterpretq_u8_u16(r0);
+      uint8x16_t r1 = vreinterpretq_u8_u16(r0);
 
       // bit test with mask giving 0x00 or 0xff
-      r2 = vtstq_u8(r1, c1);
+      uint8x16_t r2 = vtstq_u8(r1, c1);
 
       // transpose to duplicate even bytes
-      r3 = vtrn1q_u8(r2, r2);
+      uint8x16_t r3 = vtrn1q_u8(r2, r2);
 
       // transpose to duplicate odd bytes
-      r4 = vtrn2q_u8(r2, r2);
+      uint8x16_t r4 = vtrn2q_u8(r2, r2);
 
       // cast to signed 0x0000 or 0xffff
-      r5 = vreinterpretq_s16_u8(r3);
+      int16x8_t r5 = vreinterpretq_s16_u8(r3);
 
       // cast to signed 0x0000 or 0xffff
-      r6 = vreinterpretq_s16_u8(r4);
+      int16x8_t r6 = vreinterpretq_s16_u8(r4);
 
       // subtract signed 0 or -1 (i.e add 0 or 1) with saturation to counter
       *q = vqsubq_s16(*q, r5);
-      q++;
+      ++q;
 
       // subtract signed 0 or 1 (i.e. add 0 or 1) with saturation to counter
       *q = vqsubq_s16(*q, r6);
-      q++;
+      ++q;
     }
 }
 
@@ -132,30 +130,30 @@ void increment_counters_from_bitmap(count_t * counters,
 
   unsigned short * p = (unsigned short *)(bitmap);
   __vector signed short * q = (__vector signed short *) (counters);
-  int r = (totalbits + 15) / 16;
+  const auto r = (totalbits + 15) / 16;
 
-  for(int j=0; j<r; j++)
+  for(auto j = 0U; j < r; j++)
     {
-      __vector unsigned char r0, r1, r2;
-      __vector __bool char r3;
-      __vector signed short r4, r5;
+      __vector unsigned char r0;
 
       memcpy(&r0, p, 2);
-      p++;
-      r1 = vec_perm(r0, r0, c1);
-      r2 = vec_or(r1, c2);
-      r3 = vec_cmpeq(r2, c3);
-      r4 = (__vector signed short) vec_unpackl(r3);
-      r5 = (__vector signed short) vec_unpackh(r3);
+      ++p;
+      __vector unsigned char r1 = vec_perm(r0, r0, c1);
+      __vector unsigned char r2 = vec_or(r1, c2);
+      __vector __bool char r3 = vec_cmpeq(r2, c3);
+      __vector signed short r4 = (__vector signed short) vec_unpackl(r3);
+      __vector signed short r5 = (__vector signed short) vec_unpackh(r3);
       *q = vec_subs(*q, r4);
-      q++;
+      ++q;
       *q = vec_subs(*q, r5);
-      q++;
+      ++q;
     }
 }
 
 #elif __x86_64__
 
+#include <emmintrin.h>
+
 #ifdef SSSE3
 void increment_counters_from_bitmap_ssse3(count_t * counters,
                                           unsigned char * bitmap,
@@ -184,41 +182,41 @@ void increment_counters_from_bitmap_sse2(count_t * counters,
     SSE2 code.
   */
 
+  // 0xffffffff -> 1111'1111'1111'1111'1111'1111'1111'1111 (32 bits)
+  static constexpr auto all_ones = static_cast<int32_t>(0xffffffff);
+  // 0x7fbfdfef -> 0111'1111'1011'1111'1101'1111'1110'1111 (32 bits)
+  static constexpr auto mask1 = static_cast<int32_t>(0x7fbfdfef);
+  // 0xf7fbfdfe -> 1111'0111'1111'1011'1111'1101'1111'1110 (32 bits)
+  static constexpr auto mask2 = static_cast<int32_t>(0xf7fbfdfe);
+
 #ifdef SSSE3
-  const __m128i c1 =
-    _mm_set_epi32(0x01010101, 0x01010101, 0x00000000, 0x00000000);
+  const auto c1 = _mm_set_epi32(0x01010101, 0x01010101, 0x00000000, 0x00000000);
 #endif
-
-  const __m128i c2 =
-    _mm_set_epi32(0x7fbfdfef, 0xf7fbfdfe, 0x7fbfdfef, 0xf7fbfdfe);
-
-  const __m128i c3 =
-    _mm_set_epi32(0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff);
+  const auto c2 = _mm_set_epi32(mask1, mask2, mask1, mask2);
+  const auto c3 = _mm_set_epi32(all_ones, all_ones, all_ones, all_ones);
 
   auto * p = (unsigned short *)(bitmap);
   auto * q = (__m128i *)(counters);
-  int r = (totalbits + 15) / 16;
+  const auto r = (totalbits + 15) / 16;
 
-  for(int j=0; j<r; j++)
+  for(auto j = 0U; j < r; j++)
     {
-      __m128i xmm0, xmm1, xmm2, xmm3, xmm4, xmm5;
-      xmm0 = _mm_loadu_si128((__m128i*)p++);
+      const auto xmm0 = _mm_loadu_si128((__m128i *)p++);
 #ifdef SSSE3
-      xmm1 = _mm_shuffle_epi8(xmm0, c1);
+      const auto xmm1 = _mm_shuffle_epi8(xmm0, c1);
 #else
-      __m128i xmm6, xmm7;
-      xmm6 = _mm_unpacklo_epi8(xmm0, xmm0);
-      xmm7 = _mm_unpacklo_epi16(xmm6, xmm6);
-      xmm1 = _mm_unpacklo_epi32(xmm7, xmm7);
+      const auto xmm6 = _mm_unpacklo_epi8(xmm0, xmm0);
+      const auto xmm7 = _mm_unpacklo_epi16(xmm6, xmm6);
+      const auto xmm1 = _mm_unpacklo_epi32(xmm7, xmm7);
 #endif
-      xmm2 = _mm_or_si128(xmm1, c2);
-      xmm3 = _mm_cmpeq_epi8(xmm2, c3);
-      xmm4 = _mm_unpacklo_epi8(xmm3, xmm3);
-      xmm5 = _mm_unpackhi_epi8(xmm3, xmm3);
+      const auto xmm2 = _mm_or_si128(xmm1, c2);
+      const auto xmm3 = _mm_cmpeq_epi8(xmm2, c3);
+      const auto xmm4 = _mm_unpacklo_epi8(xmm3, xmm3);
+      const auto xmm5 = _mm_unpackhi_epi8(xmm3, xmm3);
       *q = _mm_subs_epi16(*q, xmm4);
-      q++;
+      ++q;
       *q = _mm_subs_epi16(*q, xmm5);
-      q++;
+      ++q;
     }
 }
 
