@@ -221,7 +221,7 @@ void derep_smallmem(char * input_filename)
 
   fastx_handle h = fastx_open(input_filename);
 
-  if (!h)
+  if (not h)
     {
       fatal("Unrecognized input file type (not proper FASTA or FASTQ format).");
     }
@@ -236,7 +236,7 @@ void derep_smallmem(char * input_filename)
   if (opt_fastaout)
     {
       fp_fastaout = fopen_output(opt_fastaout);
-      if (!fp_fastaout)
+      if (not fp_fastaout)
         {
           fatal("Unable to open FASTA output file for writing");
         }
@@ -286,12 +286,10 @@ void derep_smallmem(char * input_filename)
   uint64_t clusters = 0;
   int64_t sumsize = 0;
   uint64_t maxsize = 0;
-  double median = 0.0;
-  double average = 0.0;
 
   /* first pass */
 
-  while(fastx_next(h, ! opt_notrunclabels, chrmap_no_change))
+  while(fastx_next(h, not opt_notrunclabels, chrmap_no_change))
     {
       int64_t seqlen = fastx_get_sequence_length(h);
 
@@ -364,7 +362,7 @@ void derep_smallmem(char * input_filename)
           bp = hashtable + j;
         }
 
-      if ((opt_strand > 1) && !bp->size)
+      if ((opt_strand > 1) && not bp->size)
         {
           /* no match on plus strand */
           /* check minus strand as well */
@@ -417,7 +415,7 @@ void derep_smallmem(char * input_filename)
 
   show_rusage();
 
-  if (!opt_quiet)
+  if (not opt_quiet)
     {
       if (sequencecount > 0)
         {
@@ -500,12 +498,9 @@ void derep_smallmem(char * input_filename)
 
   show_rusage();
 
-  average = 1.0 * sumsize / clusters;
-  median = find_median();
-
   if (clusters < 1)
     {
-      if (!opt_quiet)
+      if (not opt_quiet)
         {
           fprintf(stderr,
                   "0 unique sequences\n");
@@ -518,7 +513,9 @@ void derep_smallmem(char * input_filename)
     }
   else
     {
-      if (!opt_quiet)
+      const double average = 1.0 * sumsize / clusters;
+      const auto median = find_median();
+      if (not opt_quiet)
         {
           fprintf(stderr,
                   "%" PRId64
@@ -541,7 +538,7 @@ void derep_smallmem(char * input_filename)
   /* second pass with output */
 
   fastx_handle h2 = fastx_open(input_filename);
-  if (!h2)
+  if (not h2)
     {
       fatal("Cannot open and read from the input file.");
     }
@@ -550,7 +547,7 @@ void derep_smallmem(char * input_filename)
 
   uint64_t selected = 0;
 
-  while(fastx_next(h2, ! opt_notrunclabels, chrmap_no_change))
+  while(fastx_next(h2, not opt_notrunclabels, chrmap_no_change))
     {
       int64_t seqlen = fastx_get_sequence_length(h2);
 
@@ -580,7 +577,7 @@ void derep_smallmem(char * input_filename)
           bp = hashtable + j;
         }
 
-      if ((opt_strand > 1) && ! bp->size)
+      if ((opt_strand > 1) && not bp->size)
         {
           /* no match on plus strand */
           /* check minus strand as well */
@@ -638,7 +635,7 @@ void derep_smallmem(char * input_filename)
 
   if (selected < clusters)
     {
-      if (!opt_quiet)
+      if (not opt_quiet)
         {
           fprintf(stderr,
                   "%" PRId64 " uniques written, %"
