@@ -246,7 +246,7 @@ fastx_handle fastx_open(const char * filename)
 #endif
 
   h->fp = fopen_input(filename);
-  if (!h->fp)
+  if (! h->fp)
     {
       fatal("Unable to open file for reading (%s)", filename);
     }
@@ -315,7 +315,7 @@ fastx_handle fastx_open(const char * filename)
 
       fclose(h->fp);
       h->fp = fopen_input(filename);
-      if (!h->fp)
+      if (! h->fp)
         {
           fatal("Unable to open file for reading (%s)", filename);
         }
@@ -325,11 +325,12 @@ fastx_handle fastx_open(const char * filename)
     {
       /* GZIP: Keep original file open, then open as gzipped file as well */
 #ifdef HAVE_ZLIB_H
-      if (!gz_lib)
+      if (! gz_lib)
         {
           fatal("Files compressed with gzip are not supported");
         }
-      if (! (h->fp_gz = (*gzdopen_p)(fileno(h->fp), "rb")))
+      h->fp_gz = (*gzdopen_p)(fileno(h->fp), "rb");
+      if (! h->fp_gz)
         { // dup?
           fatal("Unable to open gzip compressed file (%s)", filename);
         }
@@ -342,13 +343,14 @@ fastx_handle fastx_open(const char * filename)
     {
       /* BZIP2: Keep original file open, then open as bzipped file as well */
 #ifdef HAVE_BZLIB_H
-      if (!bz2_lib)
+      if (! bz2_lib)
         {
           fatal("Files compressed with bzip2 are not supported");
         }
-      if (! (h->fp_bz = (*BZ2_bzReadOpen_p)(& bzError, h->fp,
-                                            BZ_VERBOSE_0, BZ_MORE_MEM,
-                                            nullptr, 0)))
+      h->fp_bz = (*BZ2_bzReadOpen_p)(& bzError, h->fp,
+                                     BZ_VERBOSE_0, BZ_MORE_MEM,
+                                     nullptr, 0);
+      if (! h->fp_bz)
         {
           fatal("Unable to open bzip2 compressed file (%s)", filename);
         }
@@ -494,7 +496,7 @@ void fastx_close(fastx_handle h)
       if (opt_log)
         {
           fprintf(fp_log, "WARNING: %" PRIu64 " invalid characters stripped from %s file:", h->stripped_all, (h->is_fastq ? "FASTQ" : "FASTA"));
-          for (int i=0; i<256;i++)
+          for (int i = 0; i < 256; i++)
             {
               if (h->stripped[i])
                 {
@@ -623,7 +625,7 @@ uint64_t fastx_file_fill_buffer(fastx_handle h)
           fatal("Internal error");
         }
 
-      if (!h->is_pipe)
+      if (! h->is_pipe)
         {
 #ifdef HAVE_ZLIB_H
           if (h->format == FORMAT_GZIP)
