@@ -59,10 +59,15 @@
 */
 
 #include "vsearch.h"
+#include <cstdio>  // printf
+#include <cstdlib>  // qsort()
+
 
 /* implement a priority queue with a min heap binary array structure */
 /* elements with the lowest count should be at the top (root) */
 
+// refactoring: std::priority_queue (#include <queue>)
+
 /*
   To keep track of the n best potential target sequences, we store
   them in a min heap. The root element corresponds to the least good
@@ -73,31 +78,30 @@
   element and then the second best and so on.
 */
 
-int
-elem_smaller(elem_t * a, elem_t * b)
+auto elem_smaller(elem_t * lhs, elem_t * rhs) -> int
 {
-  /* return 1 if a is smaller than b, 0 if equal or greater */
-  if (a->count < b->count)
+  /* return 1 if lhs is smaller than rhs, 0 if equal or greater */
+  if (lhs->count < rhs->count)
     {
       return 1;
     }
   else
-    if (a->count > b->count)
+    if (lhs->count > rhs->count)
       {
         return 0;
       }
     else
-      if (a->length > b->length)
+      if (lhs->length > rhs->length)
         {
           return 1;
         }
       else
-        if (a->length < b->length)
+        if (lhs->length < rhs->length)
           {
             return 0;
           }
         else
-          if (a->seqno > b->seqno)
+          if (lhs->seqno > rhs->seqno)
             {
               return 1;
             }
@@ -107,40 +111,41 @@ elem_smaller(elem_t * a, elem_t * b)
             }
 }
 
-int minheap_compare(const void * a, const void * b)
+
+auto minheap_compare(const void * lhs_a, const void * rhs_b) -> int
 {
-  auto * x = (elem_t*) a;
-  auto * y = (elem_t*) b;
+  auto * lhs = (elem_t *) lhs_a;
+  auto * rhs = (elem_t *) rhs_b;
 
   /* return -1 if a is smaller than b, +1 if greater, otherwize 0 */
   /* first: lower count, larger length, lower seqno */
 
-  if (x->count < y->count)
+  if (lhs->count < rhs->count)
     {
       return -1;
     }
   else
-    if (x->count > y->count)
+    if (lhs->count > rhs->count)
       {
         return +1;
       }
     else
-      if (x->length > y->length)
+      if (lhs->length > rhs->length)
         {
           return -1;
         }
       else
-        if (x->length < y->length)
+        if (lhs->length < rhs->length)
           {
             return +1;
           }
         else
-          if (x->seqno > y->seqno)
+          if (lhs->seqno > rhs->seqno)
             {
               return -1;
             }
           else
-            if (x->seqno < y->seqno)
+            if (lhs->seqno < rhs->seqno)
               {
                 return +1;
               }
@@ -150,49 +155,47 @@ int minheap_compare(const void * a, const void * b)
               }
 }
 
-minheap_t *
-minheap_init(int size)
+
+auto minheap_init(int size) -> minheap_t *
 {
-  auto * m = (minheap_t *) xmalloc(sizeof(minheap_t));
-  m->alloc = size;
-  m->array = (elem_t *) xmalloc(size * sizeof(elem_t));
-  m->count = 0;
-  return m;
+  auto * a_minheap = static_cast<minheap_t *>(xmalloc(sizeof(minheap_t)));
+  a_minheap->alloc = size;
+  a_minheap->array = static_cast<elem_t *>(xmalloc(size * sizeof(elem_t)));
+  a_minheap->count = 0;
+  return a_minheap;
 }
 
-void
-minheap_exit(minheap_t * m)
+
+auto minheap_exit(minheap_t * a_minheap) -> void
 {
-  xfree(m->array);
-  xfree(m);
+  xfree(a_minheap->array);
+  xfree(a_minheap);
 }
 
-static int swaps = 0;
 
-void
-minheap_replaceroot(minheap_t * m, elem_t tmp)
+auto minheap_replaceroot(minheap_t * a_minheap, elem_t tmp) -> void
 {
   /* remove the element at the root, then swap children up
      to the root and insert tmp at suitable place */
 
   /* start with root */
-  int p = 0;
-  int c = 2*p+1;
+  int parent = 0;
+  int nth_child = 2 * parent + 1;
 
   /* while at least one child */
-  while (c < m->count)
+  while (nth_child < a_minheap->count)
     {
       /* if two children: swap with the one with smallest value */
-      if ((c + 1 < m->count) && (elem_smaller(m->array + c + 1, m->array + c)))
+      if ((nth_child + 1 < a_minheap->count) &&
+          (elem_smaller(a_minheap->array + nth_child + 1, a_minheap->array + nth_child) != 0))
         {
-          c++;
+          ++nth_child;
         }
 
       /* swap parent and child if child has lower value */
-      if (elem_smaller(m->array + c, &tmp))
+      if (elem_smaller(a_minheap->array + nth_child, &tmp) != 0)
         {
-          m->array[p] = m->array[c];
-          swaps++;
+          a_minheap->array[parent] = a_minheap->array[nth_child];
         }
       else
         {
@@ -200,132 +203,73 @@ minheap_replaceroot(minheap_t * m, elem_t tmp)
         }
 
       /* step down */
-      p = c;
-      c = 2*p+1;
+      parent = nth_child;
+      nth_child = 2 * parent + 1;
     }
 
-  m->array[p] = tmp;
+  a_minheap->array[parent] = tmp;
 }
 
 
-void
-minheap_add(minheap_t * m, elem_t * n)
+auto minheap_add(minheap_t * a_minheap, elem_t * n) -> void
 {
-  if (m->count < m->alloc)
+  if (a_minheap->count < a_minheap->alloc)
     {
       /* space for another item at end; swap upwards */
 
-      int i = m->count++;
-      int p = (i-1)/2;
-      while ((i>0) && elem_smaller(n, m->array+p))
+      int index = a_minheap->count++;
+      int pos = (index - 1) / 2;
+      while ((index > 0) && (elem_smaller(n, a_minheap->array + pos) != 0))
         {
-          m->array[i] = m->array[p];
-          i = p;
-          p = (i-1)/2;
-          swaps++;
+          a_minheap->array[index] = a_minheap->array[pos];
+          index = pos;
+          pos = (index - 1) / 2;
         }
-      m->array[i] = *n;
+      a_minheap->array[index] = *n;
     }
-  else if (elem_smaller(m->array, n))
+  else if (elem_smaller(a_minheap->array, n) != 0)
     {
       /* replace the root if new element is larger than root */
-      minheap_replaceroot(m, *n);
+      minheap_replaceroot(a_minheap, *n);
     }
 }
 
-#if 0
-inline int
-minheap_isempty(minheap_t * m)
-{
-  return !m->count;
-}
 
-inline void
-minheap_empty(minheap_t * m)
-{
-  m->count = 0;
-}
-#endif
-
-elem_t
-minheap_pop(minheap_t * m)
+auto minheap_pop(minheap_t * a_minheap) -> elem_t
 {
   /* return top element and restore order */
-  static elem_t zero = {0,0,0};
+  static const elem_t zero = {0, 0, 0};
 
-  if (m->count)
+  if (a_minheap->count != 0)
     {
-      elem_t top = m->array[0];
-      m->count--;
-      if (m->count)
+      elem_t top = a_minheap->array[0];
+      --a_minheap->count;
+      if (a_minheap->count != 0)
         {
-          elem_t tmp = m->array[m->count];
-          minheap_replaceroot(m, tmp);
+          const elem_t tmp = a_minheap->array[a_minheap->count];
+          minheap_replaceroot(a_minheap, tmp);
         }
       return top;
     }
-  else
-    {
-      return zero;
-    }
+
+  return zero;
 }
 
-void
-minheap_sort(minheap_t * m)
+
+auto minheap_sort(minheap_t * a_minheap) -> void
 {
-  qsort(m->array, m->count, sizeof(elem_t), minheap_compare);
+  std::qsort(a_minheap->array, a_minheap->count, sizeof(elem_t), minheap_compare);
 }
 
-void
-minheap_dump(minheap_t * m)
-{
-  for(int i=0; i < m->count; i++)
-    {
-      printf("%s%u", i>0 ? " " : "", m->array[i].count);
-    }
-  printf("\n");
-}
 
-elem_t
-minheap_poplast(minheap_t * m)
+auto minheap_poplast(minheap_t * a_minheap) -> elem_t
 {
   /* return top element and restore order */
-  static elem_t zero = {0,0,0};
+  static const elem_t zero = {0, 0, 0};
 
-  if (m->count)
-    {
-      return m->array[--m->count];
-    }
-  else
-    {
-      return zero;
-    }
-}
+  if (a_minheap->count != 0) {
+    return a_minheap->array[--a_minheap->count];
+  }
 
-
-void
-minheap_test()
-{
-  minheap_t * m = minheap_init(10000000);
-
-  int samples = 10000000;
-  swaps = 0;
-
-  for(int i=samples; i>=0; i--)
-    {
-      elem_t x = {(unsigned int)(rand()),0,1};
-      minheap_add(m, & x);
-    }
-
-  minheap_sort(m);
-
-  while(! minheap_isempty(m))
-    {
-      elem_t x = minheap_poplast(m);
-      printf("%u\n", x.count);
-    }
-
-  printf("Swaps: %d\n\n", swaps);
-
-  minheap_exit(m);
+  return zero;
 }
