@@ -73,21 +73,19 @@ typedef struct minheap_s
   elem_t * array;
 } minheap_t;
 
-inline int minheap_isempty(minheap_t * m)
+inline int minheap_isempty(minheap_t * a_minheap)
 {
-  return (m->count == 0);
+  return (a_minheap->count == 0);
 }
 
-inline void minheap_empty(minheap_t * m)
+inline void minheap_empty(minheap_t * a_minheap)
 {
-  m->count = 0;
+  a_minheap->count = 0;
 }
 
-elem_t minheap_poplast(minheap_t * m);
-void minheap_sort(minheap_t * m);
+elem_t minheap_poplast(minheap_t * a_minheap);
+void minheap_sort(minheap_t * a_minheap);
 minheap_t * minheap_init(int size);
-void minheap_exit(minheap_t * m);
-void minheap_add(minheap_t * m, elem_t * n);
-elem_t minheap_pop(minheap_t * m);
-
-void minheap_dump(minheap_t * m);
+void minheap_exit(minheap_t * a_minheap);
+void minheap_add(minheap_t * a_minheap, elem_t * n);
+elem_t minheap_pop(minheap_t * a_minheap);
