@@ -196,35 +196,24 @@ void results_show_blast6out_one(FILE * fp,
 
   if (hp)
     {
-      int qstart, qend;
-
-      if (hp->strand)
-        {
-          /* minus strand */
-          qstart = qseqlen;
-          qend = 1;
-        }
-      else
-        {
-          /* plus strand */
-          qstart = 1;
-          qend = qseqlen;
-        }
+      // if 'hp->strand' then 'minus strand' else 'plus strand'
+      const int qstart = hp->strand ? qseqlen : 1;
+      const int qend = hp->strand ? 1 : qseqlen;
 
       fprintf(fp,
-              "%s\t%s\t%.1f\t%d\t%d\t%d\t%d\t%d\t%d\t%" PRIu64 "\t%d\t%d\n",
-              query_head,
-              db_getheader(hp->target),
-              hp->id,
-              hp->internal_alignmentlength,
-              hp->mismatches,
-              hp->internal_gaps,
-              qstart,
-              qend,
-              1,
-              db_getsequencelen(hp->target),
-              -1,
-              0);
+	      "%s\t%s\t%.1f\t%d\t%d\t%d\t%d\t%d\t%d\t%" PRIu64 "\t%d\t%d\n",
+	      query_head,
+	      db_getheader(hp->target),
+	      hp->id,
+	      hp->internal_alignmentlength,
+	      hp->mismatches,
+	      hp->internal_gaps,
+	      qstart,
+	      qend,
+	      1,
+	      db_getsequencelen(hp->target),
+	      -1,
+	      0);
     }
   else
     {
@@ -434,7 +423,7 @@ void results_show_userout_one(FILE * fp, struct hit * hp,
                                   hp->nwalignmentlength,
                                   0);
               fprintf(fp, "%.*s",
-                      (int)(hp->internal_alignmentlength),
+                      hp->internal_alignmentlength,
                       qrow + hp->trim_q_left + hp->trim_t_left);
               xfree(qrow);
             }
@@ -447,7 +436,7 @@ void results_show_userout_one(FILE * fp, struct hit * hp,
                                   hp->nwalignmentlength,
                                   1);
               fprintf(fp, "%.*s",
-                      (int)(hp->internal_alignmentlength),
+                      hp->internal_alignmentlength,
                       trow + hp->trim_q_left + hp->trim_t_left);
               xfree(trow);
             }
