@@ -60,6 +60,10 @@
 
 #include "vsearch.h"
 
+#include <cstdint>  // int64_t
+#include <cstdio>  // FILE
+
+
 static int64_t line_pos;
 
 static char * q_seq;
@@ -79,10 +83,12 @@ static char * q_line;
 static char * a_line;
 static char * d_line;
 
-static FILE * out;
+static std::FILE * out;
 
-static int poswidth = 3;
-static int headwidth = 5;
+constexpr int poswidth_default {3};
+static int poswidth = poswidth_default;
+constexpr int headwidth_default {5};
+static int headwidth = headwidth_default;
 
 static const char * q_name;
 static const char * d_name;
@@ -92,10 +98,10 @@ static int64_t d_len;
 
 inline void putop(char c, int64_t len)
 {
-  int64_t delta = q_strand ? -1 : +1;
+  const int64_t delta = q_strand != 0 ? -1 : +1;
 
   int64_t count = len;
-  while(count)
+  while(count != 0)
     {
       if (line_pos == 0)
         {
@@ -105,24 +111,25 @@ inline void putop(char c, int64_t len)
 
       char qs;
       char ds;
-      unsigned int qs4, ds4;
+      unsigned int qs4;
+      unsigned int ds4;
 
       switch(c)
         {
         case 'M':
-          qs = q_strand ? chrmap_complement[(int)(q_seq[q_pos])] : q_seq[q_pos];
+          qs = q_strand != 0 ? chrmap_complement[static_cast<int>(q_seq[q_pos])] : q_seq[q_pos];
           ds = d_seq[d_pos];
           q_pos += delta;
           d_pos += 1;
           q_line[line_pos] = qs;
 
-          qs4 = chrmap_4bit[(int)qs];
-          ds4 = chrmap_4bit[(int)ds];
-          if ((qs4 == ds4) && (! ambiguous_4bit[qs4]))
+          qs4 = chrmap_4bit[static_cast<int>(qs)];
+          ds4 = chrmap_4bit[static_cast<int>(ds)];
+          if ((qs4 == ds4) and (ambiguous_4bit[qs4] == 0U))
             {
               a_line[line_pos] = '|';
             }
-          else if (qs4 & ds4)
+          else if ((qs4 & ds4) != 0U)
             {
               a_line[line_pos] = '+';
             }
@@ -132,16 +139,16 @@ inline void putop(char c, int64_t len)
             }
 
           d_line[line_pos] = ds;
-          line_pos++;
+          ++line_pos;
           break;
 
         case 'D':
-          qs = q_strand ? chrmap_complement[(int)(q_seq[q_pos])] : q_seq[q_pos];
+          qs = q_strand != 0 ? chrmap_complement[static_cast<int>(q_seq[q_pos])] : q_seq[q_pos];
           q_pos += delta;
           q_line[line_pos] = qs;
           a_line[line_pos] = ' ';
           d_line[line_pos] = '-';
-          line_pos++;
+          ++line_pos;
           break;
 
         case 'I':
@@ -150,35 +157,24 @@ inline void putop(char c, int64_t len)
           q_line[line_pos] = '-';
           a_line[line_pos] = ' ';
           d_line[line_pos] = ds;
-          line_pos++;
+          ++line_pos;
           break;
         }
 
-      if ((line_pos == alignlen) || ((c == 0) && (line_pos > 0)))
+      if ((line_pos == alignlen) or ((c == 0) and (line_pos > 0)))
         {
           q_line[line_pos] = 0;
           a_line[line_pos] = 0;
           d_line[line_pos] = 0;
 
-          int64_t q1 = q_start + 1;
-          if (q1 > q_len)
-            {
-              q1 = q_len;
-            }
-
-          int64_t q2 = q_strand ? q_pos +2 : q_pos;
-
-          int64_t d1 = d_start + 1;
-          if (d1 > d_len)
-            {
-              d1 = d_len;
-            }
-
-          int64_t d2 = d_pos;
+          const int64_t q1 = q_start + 1 > q_len ? q_len : q_start + 1;
+          const int64_t q2 = q_strand != 0 ? q_pos + 2 : q_pos;
+          const int64_t d1 = d_start + 1 > d_len ? d_len : d_start + 1;
+          const int64_t d2 = d_pos;
 
           fprintf(out, "\n");
           fprintf(out, "%*s %*" PRId64 " %c %s %" PRId64 "\n", headwidth, q_name, poswidth,
-                  q1, q_strand ? '-' : '+', q_line, q2);
+                  q1, q_strand != 0 ? '-' : '+', q_line, q2);
           fprintf(out, "%*s %*s   %s\n",      headwidth, "",     poswidth,
                   "", a_line);
           fprintf(out, "%*s %*" PRId64 " %c %s %" PRId64 "\n", headwidth, d_name, poswidth,
@@ -186,11 +182,11 @@ inline void putop(char c, int64_t len)
 
           line_pos = 0;
         }
-      count--;
+      --count;
     }
 }
 
-void align_show(FILE * f,
+void align_show(std::FILE * f,
                 char * seq1,
                 int64_t seq1len,
                 int64_t seq1off,
@@ -224,11 +220,11 @@ void align_show(FILE * f,
   headwidth = namewidth;
   alignlen = alignwidth;
 
-  q_line = (char*) xmalloc(alignwidth+1);
-  a_line = (char*) xmalloc(alignwidth+1);
-  d_line = (char*) xmalloc(alignwidth+1);
+  q_line = (char*) xmalloc(alignwidth + 1);
+  a_line = (char*) xmalloc(alignwidth + 1);
+  d_line = (char*) xmalloc(alignwidth + 1);
 
-  q_pos = strand ? seq1len - 1 - seq1off : seq1off;
+  q_pos = strand != 0 ? seq1len - 1 - seq1off : seq1off;
   d_pos = seq2off;
 
   line_pos = 0;
@@ -237,13 +233,13 @@ void align_show(FILE * f,
     {
       int64_t len;
       int n;
-      if (!sscanf(p, "%" PRId64 "%n", & len, & n))
+      if (sscanf(p, "%" PRId64 "%n", & len, & n) == 0)
         {
           n = 0;
           len = 1;
         }
       p += n;
-      char op = *p++;
+      const char op = *p++;
       putop(op, len);
     }
 
@@ -254,28 +250,28 @@ void align_show(FILE * f,
   xfree(d_line);
 }
 
-char * align_getrow(char * seq, char * cigar, int alen, int origin)
+char * align_getrow(char * seq, char * cigar, int alignlen, int origin)
 {
-  char * row = (char*) xmalloc(alen+1);
+  char * row = (char*) xmalloc(alignlen + 1);
   char * r = row;
   char * p = cigar;
   char * s = seq;
 
-  while(*p)
+  while(*p != 0)
     {
       int64_t len;
       int n;
-      if (!sscanf(p, "%" PRId64 "%n", & len, & n))
+      if (sscanf(p, "%" PRId64 "%n", & len, & n) == 0)
         {
           n = 0;
           len = 1;
         }
       p += n;
-      char op = *p++;
+      const char op = *p++;
 
-      if ((op == 'M') ||
-          ((op == 'D') && (origin == 0)) ||
-          ((op == 'I') && (origin == 1)))
+      if ((op == 'M') or
+          ((op == 'D') and (origin == 0)) or
+          ((op == 'I') and (origin == 1)))
         {
           strncpy(r, s, len);
           r += len;
@@ -295,10 +291,10 @@ char * align_getrow(char * seq, char * cigar, int alen, int origin)
   return row;
 }
 
-void align_fprint_uncompressed_alignment(FILE * f, char * cigar)
+void align_fprint_uncompressed_alignment(std::FILE * f, char * cigar)
 {
   char * p = cigar;
-  while(*p)
+  while (*p != 0)
     {
       if (*p > '9')
         {
