@@ -60,7 +60,7 @@
 
 #include "vsearch.h"
 
-const char * tax_letters = "dkpcofgs";
+const char * tax_letters = "dkpcofgst";
 
 bool tax_parse(const char * header,
                int header_length,
@@ -122,7 +122,7 @@ bool tax_parse(const char * header,
 
 void tax_split(int seqno, int * level_start, int * level_len)
 {
-  /* Parse taxonomy string into the following parts
+  /* Parse taxonomy string into the following 9 parts
      d domain
      k kingdom
      p phylum
@@ -131,6 +131,7 @@ void tax_split(int seqno, int * level_start, int * level_len)
      f family
      g genus
      s species
+     t strain
   */
 
   for (int i = 0; i < tax_levels; i++)
@@ -139,7 +140,8 @@ void tax_split(int seqno, int * level_start, int * level_len)
       level_len[i] = 0;
     }
 
-  int tax_start, tax_end;
+  int tax_start;
+  int tax_end;
   char * h = db_getheader(seqno);
   int hlen = db_getheaderlen(seqno);
   if (tax_parse(h, hlen, & tax_start, & tax_end))
