@@ -59,6 +59,8 @@
 */
 
 #include "vsearch.h"
+#include <cmath>
+
 
 #define BLOCKSIZE (4096 * 4096)
 
@@ -805,14 +807,15 @@ void udb_stats()
 
           fprintf(fp_log, "  %5.1f%%  %5.1f%%", pct, totpct);
 
-          int dots = int (pct / 3.0 + 0.5);
+          static constexpr double divider = 3.0;
+          const auto dots = std::lround(pct / divider);
 
           if (dots > 0)
             {
               fprintf(fp_log, "  ");
             }
 
-          for (int i = 0; i < dots ; i++)
+          for (auto i = 0L; i < dots ; i++)
             {
               fprintf(fp_log, "*");
             }
@@ -938,7 +941,7 @@ void udb_make()
   buffer[5]  = 1; /* dbstep */
   buffer[6]  = 100; /* dbaccelpct % */
   buffer[11] = 0; /* slots */
-  buffer[13] = (unsigned int) seqcount; /* number of sequences */
+  buffer[13] = seqcount; /* number of sequences */
   buffer[17] = 0x0000746e; /* alphabet: "nt" */
   buffer[49] = 0x55444266; /* fBDU UDBf */
   pos += largewrite(fd_output, buffer, 50 * 4, 0);
@@ -983,7 +986,7 @@ void udb_make()
   /* 0x005e0db3 */
   buffer[1] = 0x005e0db3;
   /* number of sequences, uint32 */
-  buffer[2] = (unsigned int) seqcount;
+  buffer[2] = seqcount;
   /* total number of nucleotides, uint64 */
   buffer[3] = (unsigned int)(ntcount & 0xffffffff);
   buffer[4] = (unsigned int)(ntcount >> 32);
